@@ -1,15 +1,22 @@
 #!/bin/sh
 #
-# cdbootflop.sh
+# bootcdflop.sh
 #
 
 MNT=/mnt
 FLOPPY=/dev/fd0
 BOOT_ONLY_WITH_FLOPPY="no"
+FSTYPES="ext3,ext2,reiserfs,iso9660,vfat,auto"
+
+# bootcdwrite modifies this script. FLOPPY could be unset.
+if [ ! "$FLOPPY" ]; then
+  echo "No Floppy device specified !!"
+  exit 0
+fi
 
 echo "Reading floppy"
-e2fsck $FLOPPY >/dev/null 2>&1 # Ignore Errors this could also be msdos
-mount $FLOPPY $MNT 
+fsck -a -t $FSTYPES $FLOPPY
+mount -v -o ro -n -t $FSTYPES $FLOPPY $MNT
 RET=$?
 
 if [ "$BOOT_ONLY_WITH_FLOPPY" = "yes" -a $RET -ne 0 ]; then
